BGGComplex
==========

.. automodule:: bggcohomology.bggcomplex
    :members:

compute_maps.py
---------------

.. automodule:: bggcohomology.compute_maps
    :members:

compute_signs.py
----------------

.. automodule:: bggcohomology.compute_signs
    :members: compute_signs
